package gs.log.v0.data

/** Default tag definitions. Tags are arbitrary strings attached to logs in the
  * `tags` field. They can be used to describe what is being logged.
  *
  * Users of this library may define their own tags -- tags are just strings.
  * These are just common examples with straightforward definitions.
  */
object LogTags:

  /** Used to flag any logs that contain PHI (Protected Health Information).
    */
  val PHI: String = "phi"

  /** Used to flag any logs that contain PII (Personally Identifiable
    * Information).
    */
  val PII: String = "pii"

  /** Used to flag any logs that contain financial information.
    */
  val Financial: String = "fin"

  /** Used to flag any logs that must be routed to a SIEM. Intended to be used
    * as an independent catch-all, and may also be used in conjunction with
    * other tags.
    */
  val SIEM: String = "siem"

  /**
   * Used to flag any logs relevant to authentication.
   */
  val Authn: String = "authn"

  /**
   * Used to flag any logs relevant to authorization.
   */
  val Authz: String = "authz"

end LogTags
